Class: Ladybug::QuerySummary
- Inherits:
-
Object
- Object
- Ladybug::QuerySummary
- Extended by:
- Loggability
- Defined in:
- lib/ladybug/query_summary.rb
Overview
Kùzu query summary class
Instance Method Summary collapse
-
#inspect ⇒ Object
Return a string representation of the receiver suitable for debugging.
Instance Method Details
#inspect ⇒ Object
Return a string representation of the receiver suitable for debugging.
18 19 20 21 22 23 24 25 26 |
# File 'lib/ladybug/query_summary.rb', line 18 def inspect details = " compiling: %0.3fs execution: %0.3fs" % [ self.compiling_time, self.execution_time, ] default = super return default.sub( />/, details + '>' ) end |